﻿Imports Microsoft.VisualBasic
Imports System.Xml
Imports System.Web
Imports System.Text
Imports System.Linq
Imports System.IO
Imports System.Diagnostics
Imports System.Data
Imports System.Collections.Generic
Imports System

Namespace CustomLocalization.Web

    ''' <summary>
    ''' This class can be used to create RESX files
    ''' </summary>
    Public NotInheritable Class DbResXConverter
        ''' <summary>
        ''' </summary>
        ''' <param name="ResourceSet"></param>
        ''' <param name="CultureName"></param>
        ''' <returns></returns>
        Private Sub New()
        End Sub
        Public Shared Function GenerateResXFileNormalizedForCulture(ByVal ResourceSet As String, ByVal CultureName As String) As XmlDocument
            Dim Data As New DbResourceDataManager()

            Dim Resources As Dictionary(Of String, String) = Data.GetResourceSetNormalizedForLocaleId(CultureName, ResourceSet)
            If Resources Is Nothing Then
                Return Nothing
            End If

            ' Load the document schema
            Dim doc As New XmlDocument()
            doc.AppendChild(doc.CreateXmlDeclaration("1.0", "utf-8", Nothing))
            doc.LoadXml(ResXDocumentTemplate)

            For Each Resource As KeyValuePair(Of String, String) In Resources
                ' Read into vars for easier usage below
                Dim ResourceKey As String = TryCast(Resource.Key, String)
                Dim ResourceValue As String = TryCast(Resource.Value, String)

                'INSTANT VB NOTE: The variable data was renamed since Visual Basic will not allow local variables with the same name as parameters or other local variables:
                Dim _data As XmlElement = doc.CreateElement("data")
                _data.SetAttribute("name", ResourceKey)

                Dim value As XmlElement = doc.CreateElement("value")
                If Not String.IsNullOrEmpty(ResourceValue) Then
                    Dim txtValue As XmlText = doc.CreateTextNode(ResourceValue)
                    value.AppendChild(txtValue)
                End If
                _data.AppendChild(value)

                doc.DocumentElement.AppendChild(_data)
            Next Resource

            Return doc
        End Function

        ''' <summary>
        ''' ResX DocumentTemplate
        ''' </summary>
        Public Const ResXDocumentTemplate As String = "<?xml version=""1.0"" encoding=""utf-8""?>" & ControlChars.CrLf & "<root>" & ControlChars.CrLf & "  <xsd:schema id=""root"" xmlns="""" xmlns:xsd=""http://www.w3.org/2001/XMLSchema"" xmlns:msdata=""urn:schemas-microsoft-com:xml-msdata"">" & ControlChars.CrLf & "    <xsd:import namespace=""http://www.w3.org/XML/1998/namespace"" />" & ControlChars.CrLf & "    <xsd:element name=""root"" msdata:IsDataSet=""true"">" & ControlChars.CrLf & "      <xsd:complexType>" & ControlChars.CrLf & "        <xsd:choice maxOccurs=""unbounded"">" & ControlChars.CrLf & "          <xsd:element name=""metadata"">" & ControlChars.CrLf & "            <xsd:complexType>" & ControlChars.CrLf & "              <xsd:sequence>" & ControlChars.CrLf & "                <xsd:element name=""value"" type=""xsd:string"" minOccurs=""0"" />" & ControlChars.CrLf & "              </xsd:sequence>" & ControlChars.CrLf & "              <xsd:attribute name=""name"" use=""required"" type=""xsd:string"" />" & ControlChars.CrLf & "              <xsd:attribute name=""type"" type=""xsd:string"" />" & ControlChars.CrLf & "              <xsd:attribute name=""mimetype"" type=""xsd:string"" />" & ControlChars.CrLf & "              <xsd:attribute ref=""xml:space"" />" & ControlChars.CrLf & "            </xsd:complexType>" & ControlChars.CrLf & "          </xsd:element>" & ControlChars.CrLf & "          <xsd:element name=""assembly"">" & ControlChars.CrLf & "            <xsd:complexType>" & ControlChars.CrLf & "              <xsd:attribute name=""alias"" type=""xsd:string"" />" & ControlChars.CrLf & "              <xsd:attribute name=""name"" type=""xsd:string"" />" & ControlChars.CrLf & "            </xsd:complexType>" & ControlChars.CrLf & "          </xsd:element>" & ControlChars.CrLf & "          <xsd:element name=""data"">" & ControlChars.CrLf & "            <xsd:complexType>" & ControlChars.CrLf & "              <xsd:sequence>" & ControlChars.CrLf & "                <xsd:element name=""value"" type=""xsd:string"" minOccurs=""0"" msdata:Ordinal=""1"" />" & ControlChars.CrLf & "                <xsd:element name=""comment"" type=""xsd:string"" minOccurs=""0"" msdata:Ordinal=""2"" />" & ControlChars.CrLf & "              </xsd:sequence>" & ControlChars.CrLf & "              <xsd:attribute name=""name"" type=""xsd:string"" use=""required"" msdata:Ordinal=""1"" />" & ControlChars.CrLf & "              <xsd:attribute name=""type"" type=""xsd:string"" msdata:Ordinal=""3"" />" & ControlChars.CrLf & "              <xsd:attribute name=""mimetype"" type=""xsd:string"" msdata:Ordinal=""4"" />" & ControlChars.CrLf & "              <xsd:attribute ref=""xml:space"" />" & ControlChars.CrLf & "            </xsd:complexType>" & ControlChars.CrLf & "          </xsd:element>" & ControlChars.CrLf & "          <xsd:element name=""resheader"">" & ControlChars.CrLf & "            <xsd:complexType>" & ControlChars.CrLf & "              <xsd:sequence>" & ControlChars.CrLf & "                <xsd:element name=""value"" type=""xsd:string"" minOccurs=""0"" msdata:Ordinal=""1"" />" & ControlChars.CrLf & "              </xsd:sequence>" & ControlChars.CrLf & "              <xsd:attribute name=""name"" type=""xsd:string"" use=""required"" />" & ControlChars.CrLf & "            </xsd:complexType>" & ControlChars.CrLf & "          </xsd:element>" & ControlChars.CrLf & "        </xsd:choice>" & ControlChars.CrLf & "      </xsd:complexType>" & ControlChars.CrLf & "    </xsd:element>" & ControlChars.CrLf & "  </xsd:schema>" & ControlChars.CrLf & "  <resheader name=""resmimetype"">" & ControlChars.CrLf & "    <value>text/microsoft-resx</value>" & ControlChars.CrLf & "  </resheader>" & ControlChars.CrLf & "  <resheader name=""version"">" & ControlChars.CrLf & "    <value>2.0</value>" & ControlChars.CrLf & "  </resheader>" & ControlChars.CrLf & "  <resheader name=""reader"">" & ControlChars.CrLf & "    <value>System.Resources.ResXResourceReader, System.Windows.Forms, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>" & ControlChars.CrLf & "  </resheader>" & ControlChars.CrLf & "  <resheader name=""writer"">" & ControlChars.CrLf & "    <value>System.Resources.ResXResourceWriter, System.Windows.Forms, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>" & ControlChars.CrLf & "  </resheader>" & ControlChars.CrLf & "</root>"

    End Class
End Namespace