﻿Imports System.Globalization
Imports System.Data.SqlClient
Imports System.Data.Common
Imports System.Data
Imports System.Configuration
Imports System.Collections.Generic
Imports System.Collections
Imports System

Namespace CustomLocalization.Web

    ''' <summary>
    ''' This class provides the Data Access to the database resources
    ''' </summary>
    Public Class DbResourceDataManager
        ''' <summary>
        ''' Default constructor. 
        ''' </summary>
        Public Sub New()
        End Sub

        ''' <summary>
        ''' Sql Connection String
        ''' </summary>
        Public ReadOnly Property ConnectionString() As String
            Get
                Return ConfigurationManager.ConnectionStrings("acmeConnectionString").ConnectionString
            End Get
        End Property

        ''' <summary>
        ''' Returns a fully normalized list of resources that contains the most specific
        ''' locale version for the culture provided.
        '''                 
        ''' This means that this routine walks the resource hierarchy and returns
        ''' the most specific value in this order: de-ch, de, invariant.
        ''' </summary>
        ''' <param name="CultureName"></param>
        ''' <param name="ResourceSet"></param>
        ''' <returns></returns>
        Public Function GetResourceSetNormalizedForLocaleId(ByVal CultureName As String, ByVal ResourceSet As String) As Dictionary(Of String, String)
            If CultureName Is Nothing Then
                CultureName = ""
            End If

            Dim resDictionary As New Dictionary(Of String, String)()

            Dim conn As SqlConnection = Nothing
            Dim cmd As SqlCommand = Nothing
            Dim reader As SqlDataReader = Nothing

            Try
                conn = New SqlConnection(ConnectionString)
                conn.Open()

                Dim sql As String = "select R.[Key], R.LocaleId, R.Value" & " from StringResource R JOIN StringResourceTag RT on RT.StringResourceId = R.Id JOIN Tag T on T.Id = RT.TagId" & " where T.Description=@ResourceSet and (LocaleId = '' {0} ) order by R.[Key], R.LocaleId DESC"

                cmd = New SqlCommand()
                cmd.CommandType = CommandType.Text
                cmd.Connection = conn

                ' use like parameter or '' if culture is empty/invariant
                Dim localeFilter As String = ""

                cmd.Parameters.AddWithValue("@ResourceSet", ResourceSet)

                If Not String.IsNullOrEmpty(CultureName) Then
                    localeFilter &= " OR LocaleId = @LocaleId"
                    cmd.Parameters.AddWithValue("@LocaleId", CultureName)

                    ' *** grab shorter version
                    If CultureName.Contains("-") Then
                        localeFilter &= " OR LocaleId = @LocaleId1"
                        cmd.Parameters.AddWithValue("@LocaleId1", CultureName.Split("-"c)(0))
                    End If
                End If

                sql = String.Format(sql, localeFilter)
                cmd.CommandText = sql

                ' Execute the query
                reader = cmd.ExecuteReader()

                If reader IsNot Nothing Then
                    Dim lastResourceKey As String = "xxxyyy"

                    Do While reader.Read()
                        ' only pick up the first ID returned - the most specific locale
                        Dim resourceKey As String = reader("Key").ToString()
                        If resourceKey = lastResourceKey Then
                            Continue Do
                        End If
                        lastResourceKey = resourceKey

                        ' Read the value into this
                        Dim resourceValue As String = Nothing
                        resourceValue = TryCast(reader("Value"), String)

                        If resourceValue Is Nothing Then
                            resourceValue = ""
                        End If

                        resDictionary.Add(resourceKey, resourceValue)
                    Loop
                End If
            Catch
            Finally
                ' close reader and connection
                If reader IsNot Nothing Then
                    reader.Close()
                End If

                If conn IsNot Nothing Then
                    conn.Close()
                End If
            End Try

            Return resDictionary
        End Function
    End Class
End Namespace