﻿Imports System
Imports System.Configuration
Imports System.Globalization
Imports System.IO
Imports System.Web
Imports System.Xml

Namespace CustomLocalization.Web
    Public Class ResxHandler
        Implements IHttpHandler
        Private Culture As CultureInfo
        Private Context As HttpContext
        Private ResourceSet As String

        Public ReadOnly Property IsReusable() As Boolean Implements IHttpHandler.IsReusable
            Get
                Return False
            End Get
        End Property

        Public Const BASERESOURCEPATH As String = "\Resources\"

        'INSTANT VB NOTE: The variable resourceBasePath was renamed since Visual Basic does not allow class members with the same name:
        Private Shared _resourceBasePath As String = Nothing

        Public Shared ReadOnly Property ResourceBasePath() As String
            Get
                If _resourceBasePath Is Nothing Then
                    _resourceBasePath = ConfigurationManager.AppSettings("ResourceBasePath")
                    If String.IsNullOrEmpty(_resourceBasePath) Then
                        _resourceBasePath = BASERESOURCEPATH
                    End If

                    If _resourceBasePath IsNot Nothing AndAlso (Not _resourceBasePath.EndsWith("\")) Then
                        _resourceBasePath &= "\"
                    End If
                End If

                Return _resourceBasePath
            End Get
        End Property

        Private Shared resourceCacheDurationSet As Boolean = False

        'INSTANT VB NOTE: The variable resourceCacheDuration was renamed since Visual Basic does not allow class members with the same name:
        Private Shared _resourceCacheDuration As TimeSpan

        Public Shared ReadOnly Property ResourceCacheDuration() As TimeSpan
            Get
                If Not resourceCacheDurationSet Then
                    resourceCacheDurationSet = True

                    ' Set to 12 hours
                    _resourceCacheDuration = New TimeSpan(12, 0, 0)

                    Dim strDuration As String = ConfigurationManager.AppSettings("ResourceCacheDuration")
                    If Not String.IsNullOrEmpty(strDuration) Then
                        Dim duration As Integer
                        If Integer.TryParse(strDuration, duration) Then
                            _resourceCacheDuration = New TimeSpan(duration, 0, 0)
                        End If
                    End If
                End If

                Return _resourceCacheDuration
            End Get
        End Property

        Public Sub ProcessRequest(ByVal context As HttpContext) Implements IHttpHandler.ProcessRequest
            Me.Context = context


            Dim culture As String = context.Request.Params("c")

            ResourceSet = context.Request.Params("rs")

            Dim resxFileInfo As New FileInfo(Me.Context.Server.MapPath(Me.Context.Request.Path))

            Dim resxFileName As String = resxFileInfo.Name
            Dim fileParts() As String = resxFileName.Split("."c)
            If fileParts.Length > 2 Then
                culture = fileParts(1)
            End If

            If fileParts.Length > 1 Then
                ResourceSet = fileParts(0)
            End If

            If Not String.IsNullOrEmpty(culture) Then
                Try
                    Me.Culture = New CultureInfo(culture)
                Catch ex As Exception
                    Dim errMsg As String = ex.Message

                    ' throw an error
                    Utilities.SendResponse(Me.Context, 500, "The string " & culture & " is not recognized as a valid culture.")
                    Return
                End Try
            End If

            ' Get the RESX file for the locale
            Dim resxFile As String = XapHandler.GetResourceFilePath(Me.Context, ResourceSet, Me.Culture.Name)

            If String.IsNullOrEmpty(resxFile) OrElse (Not File.Exists(resxFile)) Then
                Utilities.SendResponse(Me.Context, 500, "The Resx file does not exist.")
                Return
            Else
                Utilities.TransmitFile(context, resxFile, "text/xml", False)
            End If
        End Sub

    End Class
End Namespace