﻿Imports System
Imports System.IO
Imports System.Web
Imports Ionic.Zip

Namespace CustomLocalization.Web
    Public NotInheritable Class Utilities
        Private Sub New()
        End Sub
        Public Shared Sub SendResponse(ByVal context As HttpContext, ByVal statusCode As Integer, ByVal message As String)
            If context Is Nothing Then
                Return
            End If

            context.Response.StatusCode = statusCode
            If Not String.IsNullOrEmpty(message) Then
                context.Response.StatusDescription = message
            End If

            context.Response.End()
        End Sub

        Public Shared Sub AddFileToZip(ByVal _zipFile As String, ByVal fileToAdd As String, ByVal directoryPathInZip As String)
            If String.IsNullOrEmpty(_zipFile) OrElse String.IsNullOrEmpty(fileToAdd) Then
                Return
            End If
            Using zip As ZipFile = ZipFile.Read(_zipFile)
                zip.AddFile(fileToAdd, directoryPathInZip)
                zip.Save()
            End Using
        End Sub

        Public Shared Sub TransmitFile(ByVal context As HttpContext, ByVal filePath As String, ByVal contentType As String, ByVal deleteFile As Boolean)
            If context Is Nothing Then
                Return
            End If
            If String.IsNullOrEmpty(filePath) Then
                Return
            End If

            Dim file As New FileInfo(filePath)

            Try
                If file.Exists Then
                    context.Response.AppendHeader("Content-Length", file.Length.ToString())
                    context.Response.ContentType = contentType

                    If Not context.IsDebuggingEnabled Then
                        context.Response.Cache.SetCacheability(HttpCacheability.Public)
                        context.Response.ExpiresAbsolute = Date.UtcNow.AddDays(1)
                        context.Response.Cache.SetLastModified(Date.UtcNow)
                    End If

                    context.Response.TransmitFile(file.FullName)

                    If context.Response.IsClientConnected Then
                        context.Response.Flush()
                    End If
                Else
                    Utilities.SendResponse(context, 404, "File Not Found (" & filePath & ").")
                End If
            Finally
                If deleteFile AndAlso file.Exists Then
                    file.Delete()
                End If
            End Try
        End Sub

        Public Shared Function GetAppRelativePath(ByVal logicalPath As String) As String
            logicalPath = logicalPath.ToLower()

            Dim appPath As String = String.Empty

            If HttpContext.Current IsNot Nothing Then
                appPath = HttpContext.Current.Request.ApplicationPath.ToLower()
                If appPath <> "/" Then
                    appPath &= "/"
                Else
                    Return logicalPath.TrimStart("/"c)
                End If
            Else
                Return logicalPath.TrimStart("/"c)
            End If

            Return logicalPath.Replace(appPath, "")
        End Function
    End Class
End Namespace